@@ -35,6 +35,7 @@ import tarfile
 import tempfile
 from datetime import datetime
 from email.message import EmailMessage
+from functools import partial
 from io import StringIO
 from subprocess import PIPE, Popen
 from textwrap import dedent, indent
@@ -46,12 +47,12 @@ import click
 from consolekit.terminal_colours import Fore, resolve_color_default
 from consolekit.utils import abort
 from domdf_python_tools.paths import PathPlus, traverse_to_file
-from domdf_python_tools.stringlist import StringList
 from domdf_python_tools.typing import PathLike
+from domdf_python_tools.utils import divide
 from packaging.specifiers import Specifier
 from packaging.version import Version
-from shippinglabel.checksum import get_record_entry
 from shippinglabel.requirements import ComparableRequirement, combine_requirements, read_requirements
+from whey.builder import SDistBuilder, WheelBuilder
 
 # this package
 from repo_helper import __version__
@@ -61,7 +62,7 @@ from repo_helper.configuration import parse_yaml
 __all__ = ["Builder", "build_wheel", "build_sdist"]
 
 
-class Builder:
+class Builder(WheelBuilder):
 	"""
 	Builds source and binary distributions using metadata read from ``repo_helper.yml``.
 
@@ -73,25 +74,31 @@ class Builder:
 	:param verbose: Enable verbose output.
 	"""
 
+	#: The repository
+	repo_dir: PathPlus
+
 	def __init__(
 			self,
 			repo_dir: pathlib.Path,
 			build_dir: Optional[PathLike] = None,
 			out_dir: Optional[PathLike] = None,
-			verbose: bool = False
+			*,
+			verbose: bool = False,
+			colour: bool = None,
 			):
 
 		# Walk up the tree until a "repo_helper.yml" or "git_helper.yml" (old name) file is found.
 		#: The repository
-		self.repo_dir: PathPlus = traverse_to_file(PathPlus(repo_dir), "repo_helper.yml", "git_helper.yml")
-
-		#: The tag for the wheel
-		self.tag = "py3-none-any"
+		self.project_dir = self.repo_dir = traverse_to_file(
+				PathPlus(repo_dir), "repo_helper.yml", "git_helper.yml"
+				)
 
 		#: repo_helper's configuration dictionary.
 		self.config = parse_yaml(self.repo_dir, allow_unknown_keys=True)
-
 		self.config["version"] = str(Version(self.config["version"]))
+		self.config["source-dir"] = self.config["source_dir"]
+		self.config["additional-files"] = self.config["manifest_additional"]
+		self.config["package"] = self.config["import_name"]
 
 		#: The archive name, without the tag
 		self.archive_name = re.sub(
@@ -101,25 +108,22 @@ class Builder:
 				re.UNICODE,
 				) + f"-{self.config['version']}"
 
-		self.build_dir = PathPlus(build_dir or self.repo_dir / "build/repo_helper_build")
+		#: The (temporary) build directory.
+		self.build_dir = PathPlus(build_dir or self.default_build_dir)
 		self.clear_build_dir()
 		(self.build_dir / self.pkg_dir).maybe_make(parents=True)
 
-		out_dir = out_dir or self.repo_dir / "dist"
-		self.out_dir = PathPlus(out_dir)
+		#: The output directory.
+		self.out_dir = PathPlus(out_dir or self.default_out_dir)
 		self.out_dir.maybe_make(parents=True)
 
+		#: Whether to enable verbose output.
 		self.verbose = verbose
 
-	@property
-	def dist_info(self) -> PathPlus:
-		"""
-		The ``*.dist-info`` directory in the build directory.
-		"""
+		#: Whether to use coloured output.
+		self.colour = resolve_color_default(colour)
 
-		dist_info = self.build_dir / f"{self.archive_name}.dist-info"
-		dist_info.maybe_make()
-		return dist_info
+		self._echo = partial(click.echo, color=self.colour)
 
 	@property
 	def info_dir(self) -> PathPlus:
@@ -149,133 +153,27 @@ class Builder:
 
 		pkgdir = self.repo_dir / self.pkg_dir
 
+		if not pkgdir.is_dir():
+			raise FileNotFoundError(f"Package directory '{self.config['package']}' not found.")
+
+		found_file = False
+
 		for py_pattern in {"**/*.py", "**/*.pyi", "**/*.pyx", "**/py.typed"}:
 			for py_file in pkgdir.rglob(py_pattern):
 				if "__pycache__" not in py_file.parts:
+					found_file = True
 					yield py_file
 
-	def copy_source(self) -> None:
-		"""
-		Copy source files into the build directory.
-		"""
+		if not found_file:
+			raise FileNotFoundError(f"No Python source files found in {pkgdir}")
 
-		for py_file in self.iter_source_files():
-			target = self.build_dir / py_file.relative_to(self.repo_dir)
-			target.parent.maybe_make(parents=True)
-			target.write_clean(py_file.read_text())
-			self.report_copied(py_file, target)
-
-	def report_copied(self, source: pathlib.Path, target: pathlib.Path):
-		"""
-		Report that a file has been copied into the build directory.
-
-		The format is::
-
-			Copying {source} -> {target.relative_to(self.build_dir)}
-
-		:param source: The source file
-		:param target: The file in the build directory.
-		"""
-
-		if self.verbose:
-			click.echo(f"Copying {source.resolve()} -> {target.relative_to(self.build_dir)}")
-
-	def report_removed(self, removed_file: pathlib.Path):
-		"""
-		Report that a file has been removed from the build directory.
-
-		The format is::
-
-			Removing {removed_file.relative_to(self.build_dir)}
-
-		:param removed_file:
-		"""
-
-		if self.verbose:
-			click.echo(f"Removing {removed_file.relative_to(self.build_dir)}")
-
-	def report_written(self, written_file: pathlib.Path):
-		"""
-		Report that a file has been written to the build directory.
-
-		The format is::
-
-			Writing {written_file.relative_to(self.build_dir)}
-
-		:param written_file:
-		"""
-
-		if self.verbose:
-			click.echo(f"Writing {written_file.relative_to(self.build_dir)}")
-
-	def copy_manifest_additional(self) -> None:  # pylint: disable=useless-return
+	def copy_manifest_additional(self) -> None:
 		"""
 		Copy additional files to the build directory,
 		as specfied in :conf:`manifest_additional`.
 		"""  # noqa: D400
 
-		def copy_file(filename):
-			target = self.build_dir / filename.relative_to(self.repo_dir)
-			target.parent.maybe_make(parents=True)
-			shutil.copy2(src=filename, dst=target)
-			self.report_copied(filename, target)
-
-		for entry in self.config["manifest_additional"]:
-			parts = entry.split(' ')
-
-			if parts[0] == "include":
-				for include_pat in parts[1:]:
-					for include_file in self.repo_dir.glob(include_pat):
-						if include_file.is_file():
-							copy_file(filename=include_file)
-
-			elif parts[0] == "exclude":
-				for exclude_pat in parts[1:]:
-					for exclude_file in self.build_dir.glob(exclude_pat):
-						if exclude_file.is_file():
-							exclude_file.unlink()
-							self.report_removed(exclude_file)
-
-			elif parts[0] == "recursive-include":
-				for include_file in (self.repo_dir / parts[1]).rglob(parts[2]):
-					if include_file.is_file():
-						copy_file(filename=include_file)
-
-			elif parts[0] == "recursive-exclude":
-				for exclude_file in (self.build_dir / parts[1]).rglob(parts[2]):
-					if exclude_file.is_file():
-						exclude_file.unlink()
-						self.report_removed(exclude_file)
-
-		#
-		# elif parts[0] == "global-include":
-		# 	for include_pat in parts[1:]:
-		# 		for include_file in self.repo_dir.rglob(include_pat):
-		# 			if include_file.is_file():
-		# 				copy_file(filename=include_file)
-		#
-		# elif parts[0] == "global-exclude":
-		# 	for exclude_pat in parts[1:]:
-		# 		for exclude_file in self.repo_dir.rglob(exclude_pat):
-		# 			if exclude_file.is_file():
-		# 				exclude_file.unlink()
-		# 				self.report_removed(exclude_file)
-
-		#
-		# elif parts[0] == "graft":
-		# 	for graft_dir in self.repo_dir.rglob(parts[1]):
-		# 		for graft_file in graft_dir.rglob("*.*"):
-		# 			if graft_file.is_file():
-		# 				copy_file(graft_file)
-		#
-		# elif parts[0] == "prune":
-		# 	for prune_dir in self.repo_dir.rglob(parts[1]):
-		# 		for prune_file in prune_dir.rglob("*.*"):
-		# 			if prune_file.is_file():
-		# 				prune_file.unlink()
-		# 				self.report_removed(exclude_file)
-
-		return
+		self.parse_additional_files(*self.config["additional-files"])
 
 	def write_entry_points(self) -> None:
 		"""
@@ -285,27 +183,18 @@ class Builder:
 		.. TODO:: non console-script entry points.
 		"""  # noqa: D400
 
-		cfg_parser = configparser.ConfigParser()
+		self.config["scripts"] = {}
+		self.config["gui-scripts"] = {}
+		self.config["entry-points"] = {}
 
-		buf = StringList()
 		if self.config["console_scripts"]:
-			buf.append("[console_scripts]")
-			buf.extend(self.config["console_scripts"])
+			for cs in self.config["console_scripts"]:
+				name, func = divide(cs, '=')
+				self.config["scripts"][name.strip()] = func.strip()
 
-		for group, entry_points in self.config["entry_points"].items():
+		super().write_entry_points()
 
-			buf.append(f"[{group}]")
-			buf.extend(entry_points)
-
-		cfg_parser.read_string(str(buf))
-		cfg_io = StringIO()
-		cfg_parser.write(cfg_io)
-
-		entry_points_file = self.dist_info / "entry_points.txt"
-		entry_points_file.write_clean(cfg_io.getvalue())
-		self.report_written(entry_points_file)
-
-	def copy_license(self, dest_dir: PathPlus):
+	def write_license(self, dest_dir: PathPlus):
 		"""
 		Copy the any files matching ``LICEN[CS]E``.
 
@@ -318,6 +207,8 @@ class Builder:
 			target.write_clean(license_file.read_text())
 			self.report_copied(license_file, target)
 
+	copy_license = write_license
+
 	@property
 	def import_name(self) -> str:
 		"""
@@ -330,18 +221,19 @@ class Builder:
 
 	def write_metadata(self, metadata_file: PathPlus):
 		"""
-		Write `Core Metadata <https://packaging.python.org/specifications/core-metadata>`_
-		to the given file.
+		Write `Core Metadata`_ to the given file.
+
+		.. _Core Metadata: https://packaging.python.org/specifications/core-metadata
 
 		:param metadata_file:
-		"""  # noqa: D400
+		"""
 
 		github_url = "https://github.com/{username}/{repo_name}".format_map(self.config)
 
 		metadata = EmailMessage()
 		metadata["Metadata-Version"] = "2.1"
 		metadata["Name"] = self.config["pypi_name"]
-		metadata["Version"] = self.config["version"]
+		metadata["Version"] = str(self.config["version"])
 		metadata["Summary"] = self.config["short_desc"]
 		metadata["Home-page"] = github_url
 		metadata["Author"] = self.config["author"]
@@ -441,6 +333,8 @@ class Builder:
 		Write the metadata to the ``WHEEL`` file.
 		"""
 
+		# TODO: remove this once most implementation is in whey
+
 		wheel = EmailMessage()
 		wheel["Wheel-Version"] = "1.0"
 		wheel["Generator"] = f"repo_helper.build ({__version__})"
@@ -451,47 +345,6 @@ class Builder:
 		wheel_file.write_clean(str(wheel))
 		self.report_written(wheel_file)
 
-	def create_wheel_archive(self) -> str:
-		"""
-		Create the wheel archive.
-
-		:return: The filename of the created archive.
-		"""
-
-		wheel_filename = self.out_dir / f"{self.archive_name}-{self.tag}.whl"
-		self.out_dir.maybe_make(parents=True)
-
-		with ZipFile(wheel_filename, mode='w') as wheel_archive:
-			with (self.dist_info / "RECORD").open('w') as fp:
-				for file in (self.build_dir / self.pkg_dir).rglob('*'):
-					if file.is_file():
-						fp.write(get_record_entry(file, relative_to=self.build_dir))
-						fp.write('\n')
-						wheel_archive.write(file, arcname=file.relative_to(self.build_dir))
-
-				for file in self.dist_info.rglob('*'):
-					if "RECORD" in file.name and self.dist_info.name in file.parts:
-						continue
-					if not file.is_file():
-						continue
-
-					fp.write(get_record_entry(file, relative_to=self.build_dir))
-					fp.write('\n')
-					wheel_archive.write(file, arcname=file.relative_to(self.build_dir))
-
-			for file in self.dist_info.rglob("RECORD*"):
-				if file.is_file():
-					wheel_archive.write(file, arcname=file.relative_to(self.build_dir))
-					self.report_written(file)
-
-		emoji = "🎡 " if sys.platform != "win32" else ''
-		click.echo(
-				Fore.GREEN(f"{emoji}Wheel created at {wheel_filename.resolve()}"),
-				color=resolve_color_default(),
-				)
-
-		return wheel_filename.name
-
 	def create_conda_archive(self, wheel_contents_dir: PathLike, build_number: int = 1) -> str:
 		"""
 		Create the conda archive.
@@ -542,41 +395,7 @@ class Builder:
 		:return: The filename of the created archive.
 		"""
 
-		self.out_dir.maybe_make(parents=True)
-
-		sdist_filename = self.out_dir / f"{self.archive_name}.tar.gz"
-		with tarfile.open(sdist_filename, mode="w:gz", format=tarfile.PAX_FORMAT) as sdist_archive:
-			for file in self.build_dir.rglob('*'):
-				if file.is_file():
-					sdist_archive.add(str(file), arcname=file.relative_to(self.build_dir).as_posix())
-
-		click.echo(
-				Fore.GREEN(f"Source distribution created at {sdist_filename.resolve()}"),
-				color=resolve_color_default(),
-				)
-		return os.path.basename(sdist_filename)
-
-	def build_wheel(self) -> str:
-		"""
-		Build the binary wheel distribution.
-
-		:return: The filename of the created archive.
-		"""
-
-		if self.build_dir.is_dir():
-			shutil.rmtree(self.build_dir)
-		self.build_dir.maybe_make(parents=True)
-
-		self.copy_source()
-		self.copy_manifest_additional()
-		self.copy_license(self.dist_info)
-		self.write_entry_points()
-		self.write_metadata(self.dist_info / "METADATA")
-		self.write_wheel()
-		(self.dist_info / "top_level.txt").write_clean(posixpath.split(self.pkg_dir)[0])
-		self.report_written(self.dist_info / "top_level.txt")
-
-		return self.create_wheel_archive()
+		return SDistBuilder.create_sdist_archive(self)  # type: ignore
 
 	def build_sdist(self) -> str:
 		"""
@@ -636,21 +455,10 @@ class Builder:
 			pip_install_wheel(self.out_dir / wheel_file, tmpdir, self.verbose)
 			conda_filename = self.create_conda_archive(str(tmpdir), build_number=build_number)
 
-		click.echo(
-				Fore.GREEN(f"Conda package created at {(self.out_dir / conda_filename).resolve()}"),
-				color=resolve_color_default(),
-				)
+		self._echo(Fore.GREEN(f"Conda package created at {(self.out_dir / conda_filename).resolve()}"))
+
 		return conda_filename
 
-	def clear_build_dir(self) -> None:
-		"""
-		Clear the build directory of any residue from previous builds.
-		"""
-
-		if self.build_dir.is_dir():
-			shutil.rmtree(self.build_dir)
-		self.build_dir.maybe_make(parents=True)
-
 
 # copy_file(repo_dir / "__pkginfo__.py")
 # copy_file(repo_dir / "requirements.txt")
