@@ -414,6 +414,10 @@ class short_desc(ConfigVar):  # noqa
 	required = True
 	category: str = "metadata"
 
+	@classmethod
+	def validator(cls, value: str) -> str:  # noqa: D102
+		return value.strip()
+
 
 class source_dir(ConfigVar):  # noqa
 	"""
@@ -440,7 +444,7 @@ class source_dir(ConfigVar):  # noqa
 
 class pure_python(ConfigVar):  # noqa
 	"""
-	Flag to indicate the package is pure Python
+	Flag to indicate the package is pure Python.
 
 	Example:
 
@@ -456,7 +460,7 @@ class pure_python(ConfigVar):  # noqa
 
 class on_pypi(ConfigVar):  # noqa
 	"""
-	Flag to indicate the package is available on PyPI
+	Flag to indicate the package is available on PyPI.
 
 	Example:
 
