@@ -88,7 +88,7 @@ def make_actions_deploy_conda(repo_path: pathlib.Path, templates: jinja2.Environ
 @management.register("actions")
 def make_github_ci(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[str]:
 	"""
-	Add configuration for `Github Actions` to the desired repo.
+	Add configuration for `GitHub Actions` to the desired repo.
 
 	:param repo_path: Path to the repository root.
 	:param templates:
@@ -125,6 +125,24 @@ class ActionsManager:
 		self.workflows_dir = PathPlus(repo_path / ".github" / "workflows")
 		self.workflows_dir.maybe_make(parents=True)
 
+		code_file_filter: DelimitedList[str] = DelimitedList()
+
+		if self.templates.globals["enable_docs"]:
+			code_file_filter.append(f"{templates.globals['docs_dir']}/**")
+
+		code_file_filter.extend([
+				"CONTRIBUTING.rst",
+				".imgbotconfig",
+				".pre-commit-config.yaml",
+				".pylintrc",
+				".readthedocs.yml",
+				])
+		# ".bumpversion.cfg",
+		# ".style.yapf",
+		# "stubs.txt",
+
+		self._code_file_filter = f"!({code_file_filter:|})"
+
 	def get_gh_actions_python_versions(self) -> Dict[str, str]:
 		"""
 		Prepares the mapping of Python versions to tox testenvs for use with GitHub Actions.
@@ -168,6 +186,7 @@ class ActionsManager:
 							python_versions=set_gh_actions_versions(self.get_windows_ci_versions()),
 							dependency_lines=self.get_windows_ci_requirements(),
 							gh_actions_versions=self.get_gh_actions_python_versions(),
+							code_file_filter=self._code_file_filter,
 							)
 					)
 		elif ci_file.is_file():
@@ -192,6 +211,7 @@ class ActionsManager:
 							python_versions=set_gh_actions_versions(self.get_macos_ci_versions()),
 							dependency_lines=self.get_macos_ci_requirements(),
 							gh_actions_versions=self.get_gh_actions_python_versions(),
+							code_file_filter=self._code_file_filter,
 							)
 					)
 		elif ci_file.is_file():
@@ -216,6 +236,7 @@ class ActionsManager:
 							ci_name=platform_name,
 							dependency_lines=self.get_linux_ci_requirements(),
 							gh_actions_versions=self.get_gh_actions_python_versions(),
+							code_file_filter=self._code_file_filter,
 							)
 					)
 		elif ci_file.is_file():
@@ -238,6 +259,7 @@ class ActionsManager:
 					template.render(
 							ci_platform=platform_ci_names[platform_name],
 							dependency_lines=self.get_linux_ci_requirements(),
+							code_file_filter=self._code_file_filter,
 							)
 					)
 		elif ci_file.is_file():
@@ -275,7 +297,7 @@ class ActionsManager:
 		else:
 			dependencies_block = StringList([
 					"- name: Install dependencies (Linux) 🔧",
-					f"  if: ${{{{ matrix.os == '{linux_platform}' }}}}",
+					f"  if: ${{{{ matrix.os == '{linux_platform}' && steps.changes.outputs.code == 'true' }}}}",
 					"  run: |",
 					])
 			with dependencies_block.with_indent("  ", 2):
@@ -285,7 +307,7 @@ class ActionsManager:
 				dependencies_block.blankline(ensure_single=True)
 				dependencies_block.extend([
 						"- name: Install dependencies (Win/mac) 🔧",
-						f"  if: ${{{{ matrix.os != '{linux_platform}' }}}}",
+						f"  if: ${{{{ matrix.os != '{linux_platform}' && steps.changes.outputs.code == 'true' }}}}",
 						"  run: |",
 						])
 				with dependencies_block.with_indent("  ", 2):
@@ -296,11 +318,27 @@ class ActionsManager:
 						platforms=sorted(platforms),
 						linux_platform=platform_ci_names["Linux"],
 						dependencies_block=indent(str(dependencies_block), "      "),
+						code_file_filter=self._code_file_filter,
 						)
 				)
 
 		return ci_file
 
+	def make_flake8(self) -> PathPlus:
+		"""
+		Create, update or remove the flake8 action, as appropriate.
+
+		.. versionadded:: $VERSION
+		"""
+
+		ci_file = self.workflows_dir / "flake8.yml"
+		template = self.templates.get_template(ci_file.name)
+		# TODO: handle case where Linux is not a supported platform
+
+		ci_file.write_clean(template.render(code_file_filter=self._code_file_filter))
+
+		return ci_file
+
 	def get_windows_ci_versions(self) -> List[str]:
 		"""
 		Returns the Python versions to run tests for on Windows.
@@ -344,8 +382,11 @@ class ActionsManager:
 		Returns the Python requirements to run tests for on Windows.
 		"""
 
-		dependency_lines = StringList(self.standard_python_install_lines)
+		dependency_lines = StringList(self.templates.globals["github_ci_requirements"]["Windows"]["pre"])
+		dependency_lines.extend(self.standard_python_install_lines)
+
 		dependency_lines.extend(self._get_additional_requirements())
+		dependency_lines.extend(self.templates.globals["github_ci_requirements"]["Windows"]["post"])
 
 		return dependency_lines
 
@@ -354,14 +395,14 @@ class ActionsManager:
 		Returns the Python requirements to run tests for on Linux.
 		"""
 
-		dependency_lines = StringList(self.templates.globals["travis_extra_install_pre"])
+		dependency_lines = StringList(self.templates.globals["github_ci_requirements"]["Linux"]["pre"])
 		dependency_lines.extend(self.standard_python_install_lines)
 
 		if self.templates.globals["enable_tests"]:
 			dependency_lines.append("python -m pip install --upgrade coverage_pyver_pragma")
 
 		dependency_lines.extend(self._get_additional_requirements())
-		dependency_lines.extend(self.templates.globals["travis_extra_install_post"])
+		dependency_lines.extend(self.templates.globals["github_ci_requirements"]["Linux"]["post"])
 
 		return dependency_lines
 
@@ -370,9 +411,9 @@ class ActionsManager:
 		Returns the Python requirements to run tests for on Linux.
 		"""
 
-		dependency_lines = StringList(self.templates.globals["travis_extra_install_pre"])
+		dependency_lines = StringList(self.templates.globals["github_ci_requirements"]["Linux"]["pre"])
 		dependency_lines.extend(self.standard_python_install_lines)
-		dependency_lines.extend(self.templates.globals["travis_extra_install_post"])
+		dependency_lines.extend(self.templates.globals["github_ci_requirements"]["Linux"]["post"])
 
 		return dependency_lines
 
@@ -381,7 +422,13 @@ class ActionsManager:
 		Returns the Python requirements to run tests for on macOS.
 		"""
 
-		return self.get_windows_ci_requirements()
+		dependency_lines = StringList(self.templates.globals["github_ci_requirements"]["macOS"]["pre"])
+		dependency_lines.extend(self.standard_python_install_lines)
+
+		dependency_lines.extend(self._get_additional_requirements())
+		dependency_lines.extend(self.templates.globals["github_ci_requirements"]["macOS"]["post"])
+
+		return dependency_lines
 
 
 platform_ci_names = {
@@ -399,7 +446,7 @@ Mapping of platform names to the GitHub Actions platform tags.
 @management.register("conda_actions", ["enable_conda"])
 def make_conda_actions_ci(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[str]:
 	"""
-	Add configuration for testing conda paclages on `Github Actions` to the desired repo.
+	Add configuration for testing conda paclages on `GitHub Actions` to the desired repo.
 
 	:param repo_path: Path to the repository root.
 	:param templates:
@@ -432,7 +479,7 @@ def make_conda_actions_ci(repo_path: pathlib.Path, templates: jinja2.Environment
 @management.register("manylinux")
 def make_github_manylinux(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[str]:
 	"""
-	Add configuration for `Github Actions` manylinux wheel builds the desired repo.
+	Add configuration for `GitHub Actions` manylinux wheel builds the desired repo.
 
 	:param repo_path: Path to the repository root.
 	:param templates:
@@ -468,10 +515,10 @@ def make_github_manylinux(repo_path: pathlib.Path, templates: jinja2.Environment
 	return [file.relative_to(repo_path).as_posix()]
 
 
-@management.register("docs_action", ["enable_docs"])
+@management.register("docs_action")
 def make_github_docs_test(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[str]:
 	"""
-	Add configuration for Github Actions documentation check to the desired repo.
+	Add configuration for GitHub Actions documentation check to the desired repo.
 
 	:param repo_path: Path to the repository root.
 	:param templates:
@@ -479,19 +526,26 @@ def make_github_docs_test(repo_path: pathlib.Path, templates: jinja2.Environment
 
 	file = PathPlus(repo_path / ".github" / "workflows" / "docs_test_action.yml")
 	file.parent.maybe_make(parents=True)
-	if templates.globals["docs_fail_on_warning"]:
-		build_command = "tox -e docs -- -W "
-	else:
-		build_command = "tox -e docs -- "
 
-	file.write_clean(templates.get_template(file.name).render(build_command=build_command))
+	if templates.globals["enable_docs"]:
+
+		if templates.globals["docs_fail_on_warning"]:
+			build_command = "tox -e docs -- -W "
+		else:
+			build_command = "tox -e docs -- "
+
+		file.write_clean(templates.get_template(file.name).render(build_command=build_command))
+
+	else:
+		file.unlink(missing_ok=True)
+
 	return [file.relative_to(repo_path).as_posix()]
 
 
 @management.register("octocheese")
 def make_github_octocheese(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[str]:
 	"""
-	Add configuration for the OctoCheese Github Action.
+	Add configuration for the OctoCheese GitHub Action.
 
 	:param repo_path: Path to the repository root.
 	:param templates:
@@ -511,24 +565,21 @@ def make_github_octocheese(repo_path: pathlib.Path, templates: jinja2.Environmen
 @management.register("flake8_action")
 def make_github_flake8(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[str]:
 	"""
-	Add configuration for the Flake8 Github Action.
+	Add configuration for the Flake8 GitHub Action.
 
 	:param repo_path: Path to the repository root.
 	:param templates:
 	"""
 
-	file = PathPlus(repo_path / ".github" / "workflows" / "flake8.yml")
-	file.parent.maybe_make(parents=True)
+	manager = ActionsManager(repo_path, templates)
 
-	file.write_clean(templates.get_template(file.name).render())
-
-	return [file.relative_to(repo_path).as_posix()]
+	return [manager.make_flake8().relative_to(repo_path).as_posix()]
 
 
 @management.register("mypy_action")
 def make_github_mypy(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[str]:
 	"""
-	Add configuration for the mypy Github Action.
+	Add configuration for the mypy GitHub Action.
 
 	:param repo_path: Path to the repository root.
 	:param templates:
@@ -567,16 +618,24 @@ def ensure_bumpversion(repo_path: pathlib.Path, templates: jinja2.Environment) -
 	bv.read(str(bumpversion_file))
 
 	old_sections = ["bumpversion:file:git_helper.yml"]
-	required_sections = [f"bumpversion:file:{filename}" for filename in get_bumpversion_filenames(templates)]
+	required_sections = {f"bumpversion:file:{filename}" for filename in get_bumpversion_filenames(templates)}
 
 	if not templates.globals["enable_docs"]:
 		old_sections.append(f"bumpversion:file:{templates.globals['docs_dir']}/index.rst")
 
+	if not templates.globals["enable_conda"]:
+		old_sections.append(f"bumpversion:file:.github/workflows/conda_ci.yml")
+
+	if templates.globals["use_whey"]:
+		old_sections.append("bumpversion:file:setup.cfg")
+
 	for section in old_sections:
 		if section in bv.sections():
 			bv.remove_section(section)
+		if section in required_sections:
+			required_sections.remove(section)
 
-	for section in required_sections:
+	for section in sorted(required_sections):
 		if section not in bv.sections():
 			bv.add_section(section)
 
@@ -587,6 +646,23 @@ def ensure_bumpversion(repo_path: pathlib.Path, templates: jinja2.Environment) -
 			init_section["search"] = ': str = "{current_version}"'
 			init_section["replace"] = ': str = "{new_version}"'
 
+	if "bumpversion:file:setup.cfg" in bv.sections():
+		setup_cfg_section = bv["bumpversion:file:setup.cfg"]
+		if (
+				"search" not in setup_cfg_section or (
+						"search" in setup_cfg_section
+						and setup_cfg_section["search"].value == "name = {current_version}"
+						)
+				):
+			setup_cfg_section["search"] = "version = {current_version}"
+			setup_cfg_section["replace"] = "version = {new_version}"
+
+	if "bumpversion:file:pyproject.toml" in bv.sections():
+		pp_toml_section = bv["bumpversion:file:pyproject.toml"]
+		if "search" not in pp_toml_section:
+			pp_toml_section["search"] = 'version = "{current_version}"'
+			pp_toml_section["replace"] = 'version = "{new_version}"'
+
 	bv["bumpversion"]["current_version"] = templates.globals["version"]
 	bv["bumpversion"]["commit"] = "True"
 	bv["bumpversion"]["tag"] = "True"
@@ -605,11 +681,14 @@ def get_bumpversion_filenames(templates: jinja2.Environment) -> Iterable[str]:
 	:param templates:
 	"""
 
-	yield from ["pyproject.toml", "repo_helper.yml", "__pkginfo__.py", "README.rst"]
+	yield from ["pyproject.toml", "repo_helper.yml", "__pkginfo__.py", "README.rst", "setup.cfg"]
 
 	if templates.globals["enable_docs"]:
 		yield f"{templates.globals['docs_dir']}/index.rst"
 
+	if templates.globals["enable_conda"]:
+		yield ".github/workflows/conda_ci.yml"
+
 	init_filename = get_init_filename(templates)
 
 	if init_filename is not None:
