@@ -32,15 +32,17 @@ import pathlib
 import shutil
 import warnings
 from contextlib import suppress
-from typing import Dict, List, Mapping, MutableMapping, Tuple, Union
+from functools import partial
+from typing import Any, Dict, List, Mapping, MutableMapping, Tuple, Union
 
 # 3rd party
 import dict2css
+import dom_toml
 import jinja2
 import ruamel.yaml as yaml
 from domdf_python_tools.compat import importlib_resources
 from domdf_python_tools.paths import PathPlus
-from domdf_python_tools.stringlist import StringList
+from domdf_python_tools.stringlist import DelimitedList, StringList
 from domdf_python_tools.typing import PathLike
 from domdf_python_tools.utils import enquote_value
 from shippinglabel import normalize
@@ -100,6 +102,7 @@ class DocRequirementsManager(RequirementsManager):
 			# ComparableRequirement("sphinx_autodoc_typehints>=1.11.0"),
 			ComparableRequirement("sphinx-copybutton>=0.2.12"),
 			ComparableRequirement("sphinx-prompt>=1.1.0"),
+			ComparableRequirement("sphinx-pyproject>=0.1.0"),
 			}
 
 	def __init__(self, repo_path: PathLike, templates: jinja2.Environment):
@@ -131,7 +134,7 @@ class DocRequirementsManager(RequirementsManager):
 				"seed-intersphinx-mapping": ">=0.3.1",
 				"default-values": ">=0.4.2",
 				"toctree-plus": ">=0.1.0",
-				"sphinx-toolbox": ">=2.2.0",
+				"sphinx-toolbox": ">=2.10.0",
 				"sphinx-debuginfo": ">=0.1.0",
 				}
 
@@ -143,11 +146,7 @@ class DocRequirementsManager(RequirementsManager):
 		current_requirements_, comments, invalid_lines = read_requirements(self.req_file, include_invalid=True)
 
 		current_requirements = list(current_requirements_)
-
-		if "sphinx" not in current_requirements:
-			current_requirements.append(ComparableRequirement("sphinx>=3.0.3,<3.4.0"))
-		else:
-			current_requirements.append(ComparableRequirement("sphinx>=3.0.3"))
+		current_requirements.append(ComparableRequirement("sphinx>=3.0.3"))
 
 		for line in invalid_lines:
 			if line.startswith("git+"):
@@ -157,7 +156,8 @@ class DocRequirementsManager(RequirementsManager):
 
 		for req in current_requirements:
 			req.name = normalize(req.name)
-			if req.name not in self.get_target_requirement_names() and req.name not in self.theme_versions.keys():
+			# if req.name not in self.get_target_requirement_names() and req.name not in self.theme_versions.keys():
+			if req.name not in self.theme_versions.keys():
 				if req.name == "sphinx-autodoc-typehints":
 					continue
 				else:
@@ -195,7 +195,8 @@ def make_rtfd(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[st
 	"""
 
 	file = PathPlus(repo_path / ".readthedocs.yml")
-	file.parent.maybe_make()
+
+	docs_dir = PathPlus(repo_path / templates.globals["docs_dir"])
 
 	sphinx_config = {
 			"builder": "html",
@@ -209,7 +210,18 @@ def make_rtfd(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[st
 			]
 
 	install_config: List[Dict] = [{"requirements": r} for r in install_requirements]
-	install_config.append({"method": "pip", "path": '.'})
+
+	if (docs_dir / "rtd-extra-deps.txt").is_file():
+		install_config.append({"requirements": f"{templates.globals['docs_dir']}/rtd-extra-deps.txt"})
+	elif templates.globals["tox_testenv_extras"]:
+		install_config.append({
+				"method": "pip",
+				"path": '.',
+				"extra_requirements": [templates.globals["tox_testenv_extras"]],
+				})
+
+	else:
+		install_config.append({"method": "pip", "path": '.'})
 
 	python_config = {"version": 3.8, "install": install_config}
 
@@ -350,38 +362,7 @@ def make_conf(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[st
 						**templates.globals["html_theme_options"][key],
 						}
 
-	sphinx_extensions = [
-			"sphinx_toolbox",
-			"sphinx_toolbox.more_autodoc",
-			"sphinx_toolbox.more_autosummary",
-			"sphinx_toolbox.documentation_summary",
-			"sphinx_toolbox.tweaks.param_dash",
-			"sphinx_toolbox.tweaks.latex_toc",
-			"sphinx.ext.intersphinx",
-			"sphinx.ext.mathjax",
-			"sphinxcontrib.httpdomain",
-			"sphinxcontrib.extras_require",
-			"sphinx.ext.todo",
-			"sphinxemoji.sphinxemoji",
-			"notfound.extension",
-			"sphinx_copybutton",
-			"sphinxcontrib.default_values",
-			"sphinxcontrib.toctree_plus",
-			"sphinx_debuginfo",
-			"seed_intersphinx_mapping",
-			]
-	# "sphinx.ext.autosectionlabel",
-	# "sphinx_gitstamp",
-
-	sphinx_extensions.extend(templates.globals["extra_sphinx_extensions"])
-
-	file.write_clean(
-			conf.render(
-					sphinx_extensions=sphinx_extensions,
-					pformat=pformat_tabs,
-					enquote_value=enquote_value,
-					)
-			)
+	file.write_clean(conf.render(pformat=pformat_tabs, enquote_value=enquote_value))
 
 	with importlib_resources.path(repo_helper.files, "isort.cfg") as isort_config:
 		yapf_style = PathPlus(isort_config).parent.parent / "templates" / "style.yapf"
@@ -539,57 +520,14 @@ def copy_docs_styling(repo_path: pathlib.Path, templates: jinja2.Environment) ->
 
 	style_css.write_lines(style_css_lines)
 
+	with suppress(FileNotFoundError):
+		shutil.rmtree(furo_navigation.parent)
+
 	if templates.globals["sphinx_html_theme"] == "furo":
-		furo_navigation.parent.maybe_make()
-		github_url = make_github_url(templates.globals["username"], templates.globals["repo_name"])
-
-		buf = StringList([
-				"<!---{managed_message}--->".format_map(templates.globals),
-				'<div class="sidebar-tree">',
-				"  {{ furo_navigation_tree }}",
-				"</div>",
-				'',
-				'<div class="sidebar-tree">',
-				'  <p class="caption"><span class="caption-text">Links</span></p>',
-				"  <ul>",
-				f'    <li class="toctree-l1"><a class="reference external" href="{github_url}">GitHub</a></li>'
-				])
-
-		if templates.globals["on_pypi"]:
-			buf.append(
-					f'    <li class="toctree-l1"><a class="reference external" '
-					f'href="https://pypi.org/project/{templates.globals["pypi_name"]}">PyPI</a></li>'
-					)
-
-		buf.extend(["  </ul>", "</div>"])
-		buf.blankline(ensure_single=True)
-
-		furo_navigation.write_lines(buf)
-
-		base_html.write_lines([
-				f"<!--- {templates.globals['managed_message']} --->",
-				'{% extends "!base.html" %}',
-				"{% block extrahead %}",
-				'\t<link href="{{ pathto("_static/style.css", True) }}" rel="stylesheet" type="text/css">',
-				"{% endblock %}",
-				''
-				])
-
+		base_html.write_lines(_template_with_custom_css(templates.globals["managed_message"], "base.html"))
 		layout_html.unlink(missing_ok=True)
-
 	else:
-		with suppress(FileNotFoundError):
-			shutil.rmtree(furo_navigation.parent)
-
-		layout_html.write_lines([
-				f"<!--- {templates.globals['managed_message']} --->",
-				'{% extends "!layout.html" %}',
-				"{% block extrahead %}",
-				'\t<link href="{{ pathto("_static/style.css", True) }}" rel="stylesheet" type="text/css">',
-				"{% endblock %}",
-				''
-				])
-
+		layout_html.write_lines(_template_with_custom_css(templates.globals["managed_message"], "layout.html"))
 		base_html.unlink(missing_ok=True)
 
 	return [
@@ -667,10 +605,24 @@ def rewrite_docs_index(repo_path: pathlib.Path, templates: jinja2.Environment) -
 	index_rst = installation_regex.sub(install_block, index_rst)
 	index_rst = links_regex.sub(links_block, index_rst)
 	index_rst = short_desc_regex.sub(
-			".. start short_desc\n\n.. documentation-summary::\n\n.. end short_desc",
+			".. start short_desc\n\n.. documentation-summary::\n\t:meta:\n\n.. end short_desc",
 			index_rst,
 			)
 
+	if ":caption: Links" not in index_rst and not templates.globals["preserve_custom_theme"]:
+		index_rst = index_rst.replace(
+				".. start links",
+				'\n'.join([
+						".. sidebar-links::",
+						"\t:caption: Links",
+						"\t:github:",
+						(f"	:pypi: {templates.globals['pypi_name']}" if templates.globals["on_pypi"] else ''),
+						'',
+						'',
+						".. start links",
+						])
+				)
+
 	index_rst_file.write_clean(index_rst)
 
 	return [index_rst_file.relative_to(repo_path).as_posix()]
@@ -729,3 +681,138 @@ def make_docs_source_rst(repo_path: pathlib.Path, templates: jinja2.Environment)
 			docs_building_rst.relative_to(repo_path).as_posix(),
 			git_download_png.relative_to(repo_path).as_posix(),
 			]
+
+
+def make_sphinx_config_dict(templates: jinja2.Environment) -> Dict[str, Any]:
+	"""
+	Returns a dictionary of configuration values for use in ``conf.py``.
+
+	:param templates:
+	"""
+
+	data = {}
+
+	data["github_username"] = templates.globals["username"]
+	data["github_repository"] = templates.globals["repo_name"]
+	data["author"] = templates.globals["rtfd_author"]
+	data["project"] = templates.globals["modname"].replace('_', '-')
+	data["copyright"] = "{copyright_years} {author}".format_map(templates.globals)
+	data["language"] = "en"
+	data["package_root"] = templates.globals["import_name"].replace('.', '/')
+
+	data["extensions"] = [
+			"sphinx_toolbox",
+			"sphinx_toolbox.more_autodoc",
+			"sphinx_toolbox.more_autosummary",
+			"sphinx_toolbox.documentation_summary",
+			"sphinx_toolbox.tweaks.param_dash",
+			"sphinx_toolbox.tweaks.latex_layout",
+			"sphinx_toolbox.tweaks.latex_toc",
+			"sphinx.ext.intersphinx",
+			"sphinx.ext.mathjax",
+			"sphinxcontrib.httpdomain",
+			"sphinxcontrib.extras_require",
+			"sphinx.ext.todo",
+			"sphinxemoji.sphinxemoji",
+			"notfound.extension",
+			"sphinx_copybutton",
+			"sphinxcontrib.default_values",
+			"sphinxcontrib.toctree_plus",
+			"sphinx_debuginfo",
+			"seed_intersphinx_mapping",
+			*templates.globals["extra_sphinx_extensions"],
+			]
+	# "sphinx.ext.autosectionlabel",
+	# "sphinx_gitstamp",
+
+	data["sphinxemoji_style"] = "twemoji"
+	data["gitstamp_fmt"] = "%d %b %Y"
+	data["templates_path"] = ["_templates"]
+	data["html_static_path"] = ["_static"]
+	data["source_suffix"] = ".rst"
+	data["master_doc"] = "index"
+	data["suppress_warnings"] = ["image.nonlocal_uri"]
+	data["pygments_style"] = "default"
+	data["html_theme"] = templates.globals["sphinx_html_theme"].replace('-', '_')
+	data["html_theme_path"] = ["../.."]
+	data["html_show_sourcelink"] = True  # True will show link to source
+
+	data["toctree_plus_types"] = sorted({
+			"class",
+			"function",
+			"data",
+			"enum",
+			"flag",
+			"confval",
+			"directive",
+			"role",
+			"confval",
+			"protocol",
+			"typeddict",
+			"namedtuple",
+			"exception",
+			})
+
+	data["add_module_names"] = False
+	data["hide_none_rtype"] = True
+	data["all_typevars"] = True
+	data["overloads_location"] = "bottom"
+
+	# Exclude "standard" methods.
+	data["autodoc_exclude_members"] = [
+			"__dict__",
+			"__class__",
+			"__dir__",
+			"__weakref__",
+			"__module__",
+			"__annotations__",
+			"__orig_bases__",
+			"__parameters__",
+			"__subclasshook__",
+			"__init_subclass__",
+			"__attrs_attrs__",
+			"__init__",
+			"__new__",
+			"__getnewargs__",
+			"__abstractmethods__",
+			"__hash__",
+			]
+
+	return data
+
+
+class PythonFormatTomlEncoder(dom_toml.TomlEncoder):
+
+	def dump_list(self, v):  # noqa: D102
+		values = DelimitedList(str(self.dump_value(u)) for u in v)
+		single_line = f"[{values:, }]"
+
+		if len(single_line) <= self.max_width:
+			return single_line
+
+		retval = StringList(['['])
+
+		with retval.with_indent("    ", 1):
+			for u in v:
+				retval.append(f"{str(self.dump_value(u))},")
+
+		retval.append(']')
+
+		return str(retval)
+
+	def dump_value(self, v):
+		if isinstance(v, bool):
+			return str(v)
+
+		return super().dump_value(v)
+
+
+def _template_with_custom_css(managed_message: str, filename: str) -> List[str]:
+	return [
+			f"<!--- {managed_message} --->",
+			f'{{% extends "!{filename}" %}}',
+			"{% block extrahead %}",
+			'\t<link href="{{ pathto("_static/style.css", True) }}" rel="stylesheet" type="text/css">',
+			"{% endblock %}",
+			'',
+			]
