@@ -29,7 +29,7 @@ import pathlib
 import posixpath
 import re
 import textwrap
-from typing import Any, Dict, List, Tuple, TypeVar
+from typing import Any, Dict, Iterable, List, Tuple, TypeVar
 
 # 3rd party
 import dom_toml
@@ -42,8 +42,10 @@ from shippinglabel.requirements import ComparableRequirement, combine_requiremen
 # this package
 import repo_helper.files
 from repo_helper.configupdater2 import ConfigUpdater
+from repo_helper.configuration import _pypy_version_re
 from repo_helper.configuration.utils import get_version_classifiers
 from repo_helper.files import management
+from repo_helper.files.docs import make_sphinx_config_dict
 from repo_helper.utils import IniConfigurator, indent_join, indent_with_tab, license_lookup, reformat_file
 
 __all__ = [
@@ -119,6 +121,9 @@ def make_manifest(repo_path: pathlib.Path, templates: jinja2.Environment) -> Lis
 	return [file.name]
 
 
+pre_release_re = re.compile(".*(-dev|alpha|beta)", re.IGNORECASE)
+
+
 @management.register("pyproject")
 def make_pyproject(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[str]:
 	"""
@@ -174,9 +179,9 @@ def make_pyproject(repo_path: pathlib.Path, templates: jinja2.Environment) -> Li
 	data["project"]["version"] = templates.globals["version"]
 	data["project"]["description"] = templates.globals["short_desc"]
 	data["project"]["readme"] = "README.rst"
-	data["project"]["keywords"] = templates.globals["keywords"]
+	data["project"]["keywords"] = sorted(templates.globals["keywords"])
 	data["project"]["dynamic"] = ["requires-python", "classifiers", "dependencies"]
-	data["project"]["authors"] = [{"email": templates.globals["email"], "name": templates.globals["author"]}]
+	data["project"]["authors"] = [{"name": templates.globals["author"], "email": templates.globals["email"]}]
 	data["project"]["license"] = {"file": "LICENSE"}
 
 	url = "https://github.com/{username}/{repo_name}".format_map(templates.globals)
@@ -194,7 +199,7 @@ def make_pyproject(repo_path: pathlib.Path, templates: jinja2.Environment) -> Li
 	data["project"]["optional-dependencies"] = {}
 
 	for extra, dependencies in templates.globals["extras_require"].items():
-		data["project"]["optional-dependencies"][extra] = dependencies
+		data["project"]["optional-dependencies"][extra] = list(map(str, dependencies))
 
 	if not data["project"]["optional-dependencies"]:
 		del data["project"]["optional-dependencies"]
@@ -216,6 +221,14 @@ def make_pyproject(repo_path: pathlib.Path, templates: jinja2.Environment) -> Li
 
 	data.set_default("tool", {})
 
+	data["tool"].setdefault("mkrecipe", {})
+	data["tool"]["mkrecipe"]["conda-channels"] = templates.globals["conda_channels"]
+
+	if templates.globals["conda_extras"] in (["none"], ["all"]):
+		data["tool"]["mkrecipe"]["extras"] = templates.globals["conda_extras"][0]
+	else:
+		data["tool"]["mkrecipe"]["extras"] = templates.globals["conda_extras"]
+
 	if templates.globals["use_whey"]:
 		data["tool"].setdefault("whey", {})
 
@@ -227,15 +240,18 @@ def make_pyproject(repo_path: pathlib.Path, templates: jinja2.Environment) -> Li
 		for py_version in templates.globals["python_versions"]:
 			py_version = str(py_version)
 
-			if re.match(".*(-dev|alpha|beta)", py_version):
+			if pre_release_re.match(py_version):
 				continue
 
+			pypy_version_m = _pypy_version_re.match(py_version)
+
 			if py_version.startswith('3'):
 				python_versions.add(py_version)
 				python_implementations.add("CPython")
 
-			elif py_version.lower().startswith("pypy"):
+			elif pypy_version_m:
 				python_implementations.add("PyPy")
+				python_versions.add(f"3.{pypy_version_m.group(1)}")
 
 		data["tool"]["whey"]["python-versions"] = sorted(python_versions)
 		data["tool"]["whey"]["python-implementations"] = sorted(python_implementations)
@@ -260,12 +276,33 @@ def make_pyproject(repo_path: pathlib.Path, templates: jinja2.Environment) -> Li
 		if templates.globals["manifest_additional"]:
 			data["tool"]["whey"]["additional-files"] = templates.globals["manifest_additional"]
 
-	if not data["tool"]:
-		del data["tool"]
+	else:
+		if "whey" in data["tool"]:
+			del data["tool"]["whey"]
+
+		license_ = templates.globals["license"]
+		data["tool"]["mkrecipe"]["license-key"] = {v: k for k, v in license_lookup.items()}.get(license_, license_)
+
+		if templates.globals["import_name"] != templates.globals["pypi_name"]:
+			if templates.globals["stubs_package"]:
+				data["tool"]["mkrecipe"]["package"] = "{import_name}-stubs".format_map(templates.globals)
+			else:
+				data["tool"]["mkrecipe"]["package"] = posixpath.join(
+						# templates.globals["source_dir"],
+						templates.globals["import_name"].split('.', 1)[0],
+						)
 
 	if not templates.globals["enable_tests"] and not templates.globals["stubs_package"]:
 		data["tool"]["importcheck"] = data["tool"].get("importcheck", {})
 
+	if templates.globals["enable_docs"]:
+		data["tool"]["sphinx-pyproject"] = make_sphinx_config_dict(templates)
+	else:
+		data["tool"].pop("sphinx-pyproject", None)
+
+	if not data["tool"]:
+		del data["tool"]
+
 	# TODO: managed message
 	dom_toml.dump(data, pyproject_file, encoder=dom_toml.TomlEncoder)
 
@@ -353,6 +390,7 @@ class SetupCfgConfig(IniConfigurator):
 		"""
 
 		self._ini["metadata"]["name"] = self["pypi_name"]
+		self._ini["metadata"]["version"] = self["version"]
 		self._ini["metadata"]["author"] = self["author"]
 		self._ini["metadata"]["author_email"] = self["email"]
 		self._ini["metadata"]["license"] = self["license"]
