@@ -39,6 +39,7 @@ import ruamel.yaml
 from apeye.url import URL
 from domdf_python_tools.paths import PathPlus
 from domdf_python_tools.stringlist import StringList
+from ruamel.yaml import YAML
 from typing_extensions import Literal, TypedDict
 
 # this package
@@ -49,6 +50,8 @@ __all__ = ["GITHUB_COM", "make_github_url", "Hook", "Repo", "make_pre_commit"]
 #: Instance of :class:`apeye.url.URL` that points to the GitHub website.
 GITHUB_COM: URL = URL("https://github.com")
 
+yaml_safe_loader = YAML(typ="safe", pure=True)
+
 
 @functools.lru_cache()
 def make_github_url(username: str, repository: str) -> URL:
@@ -184,13 +187,13 @@ pygrep_hooks = Repo(
 
 pyupgrade = Repo(
 		repo=make_github_url("asottile", "pyupgrade"),
-		rev="v2.11.0",
+		rev="v2.12.0",
 		hooks=[{"id": "pyupgrade", "args": ["--py36-plus", "--keep-runtime-typing"]}]
 		)
 
 lucas_c_hooks = Repo(
 		repo=make_github_url("Lucas-C", "pre-commit-hooks"),
-		rev="v1.1.9",
+		rev="v1.1.10",
 		hooks=["remove-crlf", "forbid-crlf"],
 		)
 
@@ -200,6 +203,12 @@ flake2lint = Repo(
 		hooks=["flake2lint"],
 		)
 
+pyproject_parser = Repo(
+		repo=make_github_url("repo-helper", "pyproject-parser"),
+		rev="v0.2.3",
+		hooks=["reformat-pyproject"],  # TODO: add check-pyproject
+		)
+
 # shellcheck = Repo(
 # 		repo=make_github_url("shellcheck-py", "shellcheck-py"),
 # 		rev="v0.7.1.1",
@@ -231,12 +240,7 @@ def make_pre_commit(repo_path: pathlib.Path, templates: jinja2.Environment) -> L
 	import_name = templates.globals["import_name"]
 	stubs_package = templates.globals["stubs_package"]
 
-	non_source_files = [
-			posixpath.join(docs_dir, "conf"),
-			"__pkginfo__",
-			"make_conda_recipe",
-			"setup",
-			]
+	non_source_files = [posixpath.join(docs_dir, "conf"), "__pkginfo__", "setup"]
 
 	domdfcoding_hooks = Repo(
 			repo=make_github_url("domdfcoding", "pre-commit-hooks"),
@@ -264,7 +268,7 @@ def make_pre_commit(repo_path: pathlib.Path, templates: jinja2.Environment) -> L
 
 	formate = Repo(
 			repo=make_github_url("repo-helper", "formate"),
-			rev="v0.4.3",
+			rev="v0.4.5",
 			hooks=[{"id": "formate", "exclude": formate_excludes}],
 			)
 
@@ -275,7 +279,7 @@ def make_pre_commit(repo_path: pathlib.Path, templates: jinja2.Environment) -> L
 
 	dep_checker = Repo(
 			repo=make_github_url("domdfcoding", "dep_checker"),
-			rev="v0.6.0",
+			rev="v0.6.2",
 			hooks=[{"id": "dep_checker", "args": dep_checker_args}]
 			)
 
@@ -299,6 +303,7 @@ def make_pre_commit(repo_path: pathlib.Path, templates: jinja2.Environment) -> L
 	indent_re = re.compile("^ {3}")
 
 	managed_hooks = [
+			pyproject_parser,
 			pre_commit_hooks,
 			domdfcoding_hooks,
 			flake8_dunder_all,
@@ -331,7 +336,7 @@ def make_pre_commit(repo_path: pathlib.Path, templates: jinja2.Environment) -> L
 
 		custom_hooks = [
 				Repo(**repo)
-				for repo in ruamel.yaml.safe_load(custom_hooks_yaml) or []
+				for repo in yaml_safe_loader.load(custom_hooks_yaml) or []
 				if repo["repo"] not in managed_hooks_urls
 				]
 
