@@ -337,7 +337,7 @@ class ToxConfig(IniConfigurator):
 			# 		f"-r{{toxinidir}}/{self['docs_dir']}/requirements.txt",
 			# 		], )
 
-			self._ini["testenv:docs"]["commands"] = "sphinx-build -M html . ./build {posargs}"
+			self._ini["testenv:docs"]["commands"] = "sphinx-build -M {env:SPHINX_BUILDER:html} . ./build {posargs}"
 
 		else:
 			self._ini.remove_section("testenv:docs")
@@ -381,8 +381,8 @@ class ToxConfig(IniConfigurator):
 			self._ini["testenv:lint"]["skip_install"] = True
 
 		self._ini["testenv:lint"]["deps"] = indent_join([
-				"flake8 >=3.8.2",
-				"flake8-2020 >= 1.6.0",
+				"flake8>=3.8.2",
+				"flake8-2020>=1.6.0",
 				"flake8-builtins>=1.5.3",
 				"flake8-docstrings>=1.5.0",
 				"flake8-dunder-all>=0.1.1",
@@ -399,6 +399,7 @@ class ToxConfig(IniConfigurator):
 				"git+https://github.com/domdfcoding/flake8-rst-docstrings.git",
 				"pydocstyle>=6.0.0",
 				"pygments>=2.7.1",
+				"importlib_metadata<4.5.0; python_version<'3.8'"
 				])
 		cmd = f"python3 -m flake8_rst_docstrings_sphinx {' '.join(self.get_source_files())} --allow-toolbox {{posargs}}"
 		self._ini["testenv:lint"]["commands"] = cmd
@@ -451,6 +452,11 @@ class ToxConfig(IniConfigurator):
 			self._ini["testenv:coverage"]["skip_install"] = True
 			self._ini["testenv:coverage"]["ignore_errors"] = True
 			self._ini["testenv:coverage"]["whitelist_externals"] = "/bin/bash"
+			self._ini["testenv:coverage"]["passenv"] = indent_join([
+					"COV_PYTHON_VERSION",
+					"COV_PLATFORM",
+					"COV_PYTHON_IMPLEMENTATION",
+					])
 			self._ini["testenv:coverage"]["changedir"] = "{toxinidir}"
 
 			coverage_deps = ["coverage>=5"]
@@ -809,9 +815,9 @@ class TestsRequirementsManager(RequirementsManager):
 			ComparableRequirement("coverage>=5.1"),
 			ComparableRequirement("pytest>=6.0.0"),
 			ComparableRequirement("pytest-cov>=2.8.1"),
-			ComparableRequirement("pytest-randomly>=3.3.1"),
-			ComparableRequirement("pytest-timeout>=1.4.2"),  # ComparableRequirement("pytest-rerunfailures>=9.0"),
-			ComparableRequirement("iniconfig!=1.1.0,>=1.0.1"),
+			ComparableRequirement("importlib-metadata>=3.6.0"),
+			ComparableRequirement("pytest-randomly>=3.7.0"),
+			ComparableRequirement("pytest-timeout>=1.4.2"),
 			}
 
 	def __init__(self, repo_path: PathLike, templates: jinja2.Environment):
@@ -822,8 +828,6 @@ class TestsRequirementsManager(RequirementsManager):
 	def compile_target_requirements(self) -> None:
 		if self._globals["pypi_name"] != "coverage_pyver_pragma":
 			self.target_requirements.add(ComparableRequirement("coverage-pyver-pragma>=0.2.1"))
-		if self._globals["pypi_name"] != "domdf_python_tools":
-			self.target_requirements.add(ComparableRequirement("domdf-python-tools[testing]>=2.0.1"))
 		if self._globals["pypi_name"] != "coincidence":
 			self.target_requirements.add(ComparableRequirement("coincidence>=0.2.0"))
 
